<?php

namespace Drupal\live_css\Form;

use Drupal\system\SystemConfigFormBase;
use function Drupal\live_css\Form\config;
use function Drupal\live_css\Form\drupal_build_form;
use function Drupal\live_css\Form\drupal_set_message;

/**
 * Use Drupal\Core\Form\ConfigFormBase;.
 */
class LiveCSSAdmin extends SystemConfigFormBase {

  private $config = [];

  /**
   *
   */
  public function getFormID() {
    return 'css_settings_form';
  }

  /**
   *
   */
  public function settings(array $form, array &$form_state) {
    $form_state['build_info']['args'] = [];
    $form_state['build_info']['callback'] = [$this, 'buildForm'];
    return drupal_build_form('css_settings_form', $form_state);
  }

  /**
   *
   */
  public function buildForm(array $form, array &$form_state) {
    $this->config = config('live_css.settings');
    $form['live_css_less'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable LESS Support'),
      '#default_value' => $this->config->get('live_css_less'),
      '#description' => $this->t('Allows the live editing and display of LESS files on
			 the site, by simply embedding stylesheets with a "less" extension instead
			 of "css". The Less is parsed on each page load, even for anonymous
			 users. In production you may wish to disable this feature and use the
			 LESS module instead.'),
    ];
    $form['live_css_flush'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('CSS and JS cache flush'),
      '#default_value' => $this->config->get('live_css_flush'),
      '#description' => $this->t('Flush CSS and Javascript cache on every save.'),
    ];
    $form['live_css_hideadmin'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide Admin Menu'),
      '#default_value' => $this->config->get('live_css_hideadmin'),
      '#description' => $this->t('Automatically hides the administration menu when
			 editing CSS.'),
    ];
    $form['live_css_hidemodules'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Only show theme CSS'),
      '#default_value' => $this->config->get('live_css_hidemodules'),
      '#description' => $this->t('Removes module and other styles from the CSS list.'),
    ];
    $form['live_css_storage'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Consistent Editor State'),
      '#default_value' => $this->config->get('live_css_storage'),
      '#description' => $this->t('Remembers the current file and file position to
			 maintain this between page loads.'),
    ];
    $form['live_css_theme'] = [
      '#type' => 'select',
      '#title' => $this->t('Editor Theme'),
      '#default_value' => $this->config->get('live_css_theme'),
      '#options' => live_css_list_themes(),
    ];
    $form['live_css_fontsize'] = [
      '#type' => 'select',
      '#title' => $this->t('Font Size'),
      '#default_value' => $this->config->get('live_css_fontsize'),
      '#options' => [
        '8px' => '8px',
        '10px' => '10px',
        '11px' => '11px',
        '12px' => '12px',
        '14px' => '14px',
        '16px' => '16px',
        '18px' => '18px',
      ],
    ];
    $form['live_css_softtabs'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Soft Tabs'),
      '#default_value' => $this->config->get('live_css_softtabs'),
      '#description' => $this->t('Use spaces instead of a tab character.'),
    ];
    $form['live_css_tabsize'] = [
      '#type' => 'select',
      '#title' => $this->t('Tab Size'),
      '#default_value' => $this->config->get('live_css_tabsize'),
      '#description' => $this->t('When using soft tabs, specify how many spaces to
			 insert for the tab character.'),
      '#options' => [
        1 => '1',
        2 => '2',
        3 => '3',
        4 => '4',
      ],
    ];
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#button_type' => 'primary',
    ];
    $form['#theme'] = 'system_config_form';
    return $form;
  }

  /**
   *
   */
  public function submitForm(array &$form, array &$form_state) {
    $this->config->set('live_css_less', $form_state['values']['live_css_less']);
    $this->config->set('live_css_flush', $form_state['values']['live_css_flush']);
    $this->config->set('live_css_hideadmin', $form_state['values']['live_css_hideadmin']);
    $this->config->set('live_css_hidemodules', $form_state['values']['live_css_hidemodules']);
    $this->config->set('live_css_storage', $form_state['values']['live_css_storage']);
    $this->config->set('live_css_theme', $form_state['values']['live_css_theme']);
    $this->config->set('live_css_fontsize', $form_state['values']['live_css_fontsize']);
    $this->config->set('live_css_softtabs', $form_state['values']['live_css_softtabs']);
    $this->config->set('live_css_tabsize', $form_state['values']['live_css_tabsize']);
    $this->config->save();
    drupal_set_message(t('The Live CSS settings below have been applied.'));
  }

}
